<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
//
// Update: Konrad Roziewski <konrad at suwalki com pl>

$index_text = array (

'search'	=>	'Szukaj',
'alltasktypes'	=>	'Dowolny typ',
'allseverities'	=>	'Dowolna ważność',
'alldevelopers'	=>	'Wszyscy programiści',
'notyetassigned'=>	'Zadania nieprzydzielone',
'allcategories'	=>	'Dowolna kategoria',
'allstatuses'	=>	'Dowolny status',
'allopentasks'	=>	'Zgłoszenia otwarte',
'sortthiscolumn'=>	'Sortuj według kolumny',
'id'		=>	'ID',
'tasktype'	=>	'Typ zgłoszenia',
'severity'	=>	'Ważność',
'summary'	=>	'Skrócony opis',
'dateopened'	=>	'Data otwarcia',
'status'	=>	'Status',
'progress'	=>	'Postęp',
'complete'	=>	'gotowe',
'previous'	=>	'Poprzedni',
'next'		=>	'Następny',

// Added in version 0.9.5
'searchthisproject'	=>	'Szukaj w bieżącym projekcie',

// Added in version 0.9.6
'closed'		=>	'Zamknięte',
'dueanyversion'		=>	'Obecne do dowolnej wersji',
'dueversion'		=>	'Obecne do wersji',
'project'		=>	'Projekt',
'category'		=>	'Kategoria',
'lastedit'		=>	'Data ostatniej edycji',
'assignedto'		=>	'Przydzielone dla',
'os'			=>	'System operacyjny',
'reportedin'		=>	'Dotyczy wersji',
'openedby'		=>	'Zgłoszone przez',
'comments'          	=>	'Komentarze',
'attachments'		=>	'Załączniki',
'priority'		=>	'Priorytet',


);
// vim:fenc=utf-8:enc=utf-8
?>
